summaryrefslogtreecommitdiffstats
path: root/libkdepim/kregexp3.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /libkdepim/kregexp3.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdepim/kregexp3.h')
-rw-r--r--libkdepim/kregexp3.h38
1 files changed, 19 insertions, 19 deletions
diff --git a/libkdepim/kregexp3.h b/libkdepim/kregexp3.h
index c9b53c5f..64a874d3 100644
--- a/libkdepim/kregexp3.h
+++ b/libkdepim/kregexp3.h
@@ -19,11 +19,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this library with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -36,21 +36,21 @@
#include <kdepimmacros.h>
/** @short A TQRegExp (Qt3.x) with a tqreplace() method.
This class is simply there to provide a namespace for some nice
- enhancements of the mighty TQRegExp (Qt3 version) regular
+ enhancements of the mighty TQRegExp (TQt3 version) regular
expression engine, namely the method tqreplace(), which can be
- used to do search-and-tqreplace like one is used to from perl or sed.
+ used to do search-and-replace like one is used to from perl or sed.
- It "simply" adds the ability to define a tqreplacement string which
- tqcontains references to the captured substrings. The following
+ It "simply" adds the ability to define a replacement string which
+ contains references to the captured substrings. The following
constructs are understood, which can be freely mixed in the
- tqreplacement string:
+ replacement string:
@section Sed syntax
- Back references in the tqreplacement string are made using \n
+ Back references in the replacement string are made using \n
(backslash-digit), where @p n is a single digit. With this mode of
operation, only the first nine captured substrings can be
referenced.
@@ -60,7 +60,7 @@
@section Perl syntax
- Back references in the tqreplacement string are made using $n
+ Back references in the replacement string are made using $n
(dollarsign-digit), where @p n is a single digit. With this mode
of operation, only the first nine captured substrings can be
referenced.
@@ -73,10 +73,10 @@
To reference the entire matched string, use $0, ${0} or \\0.
@author Marc Mutz <mutz@kde.org>
- @see QRegExp
+ @see TQRegExp
*/
-class KDE_EXPORT KRegExp3 : public QRegExp
+class KDE_EXPORT KRegExp3 : public TQRegExp
{
public:
KRegExp3()
@@ -91,21 +91,21 @@ public:
: TQRegExp( (TQRegExp)rx ) {}
/** Replaces each matching subpattern in @p str with
- @p tqreplacementStr, inserting captured substrings for
+ @p replacementStr, inserting captured substrings for
\\n, $n and ${nn} as described in the class documentation.
@param str The source string.
- @param tqreplacementStr The string which tqreplaces matched
+ @param replacementStr The string which replaces matched
substrings of @p str.
@param start Start position for the search.
If @p start is negative, starts @p -(start) positions
from the end of @p str.
- @param global If @p TRUE, requests to tqreplace all occurrences
- of the regexp with @p tqreplacementStr; if @p FALSE,
- only the first occurrence will be tqreplaced.
+ @param global If @p TRUE, requests to replace all occurrences
+ of the regexp with @p replacementStr; if @p FALSE,
+ only the first occurrence will be replaced.
Equivalent to the /g switch to perl's s/// operator.
@return The modified string.
*/
TQString tqreplace( const TQString & str,
- const TQString & tqreplacementStr,
+ const TQString & replacementStr,
int start=0, bool global=TRUE );
};
@@ -36,21 +36,21 @@
#include <kdepimmacros.h>
-/** @short A TQRegExp (Qt3.x) with a tqreplace() method.
+/** @short A TQRegExp (TQt3.x) with a tqreplace() method.
This class is simply there to provide a namespace for some nice